@@ -1,7 +1,7 @@
 """ Team endpoint """
+from typing import Dict, Any
 import requests
 from requests.exceptions import HTTPError
-import pandas as pd
 from .base import BaseEndpoint
 from ..exceptions import InvalidTeam, PrimaryAttribute
 
@@ -52,7 +52,7 @@ class TeamEndpoint(BaseEndpoint):
 
     def _get_data(
         self, season: str, query: str, **kwargs: str
-    ) -> pd.DataFrame:
+    ) -> Dict[str, Any]:
         """
         Get data on a per-team basis
 
@@ -64,17 +64,19 @@ class TeamEndpoint(BaseEndpoint):
         """
         if not isinstance(self.team, str):
             raise TypeError("``team`` must be a string")
-        self._check_args(query=query)
+        self._check_args()
         url = self.base_url + "team/" + self.team + "/" + season
 
         try:
             data = self._get_response(url=url, query=query, **kwargs)
         except HTTPError as err:
-            raise InvalidTeam(self.team) from err
+            raise InvalidTeam(
+                f"{self.team} is not a valid team", team=self.team
+            ) from err
 
         return data
 
-    def get_player_data(self, season: str, **kwargs: str) -> pd.DataFrame:
+    def get_player_data(self, season: str, **kwargs: str) -> Dict[str, Any]:
         """
         Get data for all players on a given team in a given season
 
@@ -85,7 +87,7 @@ class TeamEndpoint(BaseEndpoint):
         data = self._get_data(season=season, query="playersData", **kwargs)
         return data
 
-    def get_match_data(self, season: str, **kwargs: str) -> pd.DataFrame:
+    def get_match_data(self, season: str, **kwargs: str) -> Dict[str, Any]:
         """
         Get data on a per match level for a given team in a given season
 
@@ -100,7 +102,7 @@ class TeamEndpoint(BaseEndpoint):
         self,
         season: str,
         **kwargs: str,
-    ) -> pd.DataFrame:
+    ) -> Dict[str, Any]:
         """
         Get data based on different contexts in the game
 
@@ -108,7 +110,5 @@ class TeamEndpoint(BaseEndpoint):
         :param kwargs: Keyword argument to pass to
             :meth:`understatapi.endpoints.base.BaseEndpoint._get_response`
         """
-        data = self._get_data(
-            season=season, query="statisticsData", **kwargs
-        ).T
+        data = self._get_data(season=season, query="statisticsData", **kwargs)
         return data
